# aceso [![Build Status](https://travis-ci.org/tetraptych/aceso.svg?branch=master)](https://travis-ci.org/tetraptych/unrasterize) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
Aceso is a lightweight package to calculate 2SFCA and other measures of spatial accessibility.
